==> haskell-named-text-1.2.1.0-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-named-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 named-text
version:              1.2.1.0
visibility:           public
id:                   named-text-1.2.1.0-DszS2iqo8Id4PHQpGXIgQL
key:                  named-text-1.2.1.0-DszS2iqo8Id4PHQpGXIgQL
license:              ISC
copyright:            Galois Inc, 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:
    A parameterized named text type and associated functionality.

description:

    A plain String or Text is dangerous because it can be arbitrarily combined,
    converted, emitted, and updated without consideration of the validity and
    applicability of the contents and the usage scenario.

    This module provides a Named type wrapper around Text which has two
    additional type parameters: one which indicates what the content of the Text
    represents, and one which indicates the style of the name.

    There are additionally functions and classes which allow conversions and
    transformations between names with different styles and types (or disallow them
    where appropriate).

    The core intent of this library is that the Named is used instead of a raw
    String or Text to provide type-level tracking and safety.

category:             Data
abi:                  bc50032fdfd364e7e682cd8beb87ca47
exposed:              True
exposed-modules:      Data.Name Data.Name.JSON
hidden-modules:       Data.Name.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-named-text
hs-libraries:         HSnamed-text-1.2.1.0-DszS2iqo8Id4PHQpGXIgQL
depends:
    aeson-2.1.2.1-FLNpA1kYfSp7ISjZQSk2AY base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.6.0-AVmZwVVVmv9PclG6VBq0Z
    prettyprinter-1.7.1-6LAznmhuiuZGYtT9LOkZPA
    sayable-1.2.5.0-EKrEr8mo4uFHZq11AJ8ooc text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-named-text/html/named-text.haddock
haddock-html:         /usr/share/doc/haskell-named-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-named-text-1.2.1.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-named-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 named-text
version:              1.2.1.0
visibility:           public
id:                   named-text-1.2.1.0-FY8mQAETDitIxZiHtvx8RF
key:                  named-text-1.2.1.0-FY8mQAETDitIxZiHtvx8RF
license:              ISC
copyright:            Galois Inc, 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:
    A parameterized named text type and associated functionality.

description:

    A plain String or Text is dangerous because it can be arbitrarily combined,
    converted, emitted, and updated without consideration of the validity and
    applicability of the contents and the usage scenario.

    This module provides a Named type wrapper around Text which has two
    additional type parameters: one which indicates what the content of the Text
    represents, and one which indicates the style of the name.

    There are additionally functions and classes which allow conversions and
    transformations between names with different styles and types (or disallow them
    where appropriate).

    The core intent of this library is that the Named is used instead of a raw
    String or Text to provide type-level tracking and safety.

category:             Data
abi:                  3f44bcbfabc0ab6ae74cff682e2b938b
exposed:              True
exposed-modules:      Data.Name Data.Name.JSON
hidden-modules:       Data.Name.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-named-text
hs-libraries:         HSnamed-text-1.2.1.0-FY8mQAETDitIxZiHtvx8RF
depends:
    aeson-2.1.2.1-AErwMfn2r5g1Pc6FekWoJb base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.6.0-HNsjIjcKtfz4EPsBV3Crzv
    prettyprinter-1.7.1-KHTd6ELn8JD9j39b7JIrXU
    sayable-1.2.5.0-KCQOh3G7uUS3g30IBfY4Ag text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-named-text/html/named-text.haddock
haddock-html:         /usr/share/doc/haskell-named-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
